@@ -80,11 +80,7 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
 
   message(nb_files, " files found; importing spectra:")
 
-  if (!interpolate) {
-    gsp <- function(f) {
-      dispatch_parser(f, decimal = decimal, sep = sep)[[1]]
-    }
-  } else {
+  if (interpolate) {
     gsp <- function(f) {
       df <- dispatch_parser(f, decimal = decimal, sep = sep)[[1]]
 
@@ -98,12 +94,15 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
                 call. = FALSE)
         return(NULL)
       }
-
       df <- df[c(min(bounds) - 1, bounds, max(bounds) + 1), ]
 
       approx(df[, "wl"], df[, "processed"],
              xout = range, ties = "ordered")$y
     }
+  } else {
+    gsp <- function(f) {
+      dispatch_parser(f, decimal = decimal, sep = sep)[[1]]
+    }
   }
 
   with_progress({
@@ -113,7 +112,7 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
       tryCatch(
         gsp(x),
         error = function(e) {
-          warning(conditionMessage(e))
+          warning(conditionMessage(e), call. = FALSE)
           return(NULL)
         }
       )
@@ -129,7 +128,7 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
   } else if (length(whichfailed) > 0) {
 
     warning("Could not import one or more files:\n",
-      paste0(files[whichfailed], collapse = "\n"),
+      paste(files[whichfailed], collapse = "\n"),
       call. = FALSE
     )
 
@@ -139,7 +138,10 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
   if (interpolate) {
     # We convert to data.frame before adding the wl to preserve wl class (int or
     # altrep)
-    tmp <- as.data.frame(do.call(cbind, tmp))
+
+    # Errors have created NULL elements that we need to remove
+    tmp <- tmp[lengths(tmp) != 0]
+    tmp <- list2DF(tmp)
 
     final <- cbind(range, tmp)
   } else {
@@ -147,10 +149,10 @@ lr_get_spec <- function(where = getwd(), ext = "txt", lim = c(300, 700),
       stop("'interpolate = FALSE' can only work if all input files sample the ",
            "same wavelengths.", call. = FALSE)
     }
-    final <- as.data.frame(
-      do.call(cbind, lapply(tmp, function(x) x[, "processed"]))
-    )
 
+    # Errors have created NULL elements that we need to remove
+    tmp <- tmp[lengths(tmp) != 0]
+    final <- list2DF(lapply(tmp, function(x) x[, "processed"]))
     final <- cbind(tmp[[1]][, "wl"], final)
 
     # This steps needs to be only run when !interp because it breaks altrep
