@@ -1,7 +1,7 @@
-#' Parse OceanInsight converted file
+#' Parse OceanOptics converted file
 #'
-#' Parse OceanInsight (formerly OceanOptics) converted file.
-#' <https://www.oceaninsight.com/>
+#' Parse OceanOptics/OceanInsight converted file.
+#' <https://www.oceanoptics.com/>
 #'
 #' @inheritParams lr_parse_generic
 #'
@@ -61,6 +61,8 @@ lr_parse_jaz <- function(filename) {
   tz <- ""
 
   if (grepl(oo_savetime_regex, savetime)) {
+    # The value we extract here might not follow the official naming and could
+    # not be recognized by tzdata.
     tz <- trimws(gsub(oo_savetime_regex, "\\2", savetime))
     savetime <- gsub(oo_savetime_regex, "\\1 \\3", savetime)
   }
@@ -68,6 +70,7 @@ lr_parse_jaz <- function(filename) {
   if (tz == "") {
     tz <- "UTC"
   }
+  tz <- convert_backward_tzdata(tz)
 
   # OceanOptics files use locale-dependent date formats but it looks like they
   # are always using English for this, even when the locale is not set to
@@ -150,11 +153,11 @@ lr_parse_jaz <- function(filename) {
   }
   storage.mode(data) <- "numeric"
 
-  cornames <- c("wl" = "W",
-                "dark" = "D",
-                "white" = "R",
-                "scope" = "S",
-                "processed" = "P")
+  cornames <- c(wl = "W",
+                dark = "D",
+                white = "R",
+                scope = "S",
+                processed = "P")
 
   data_final <- setNames(
     as.data.frame(matrix(NA_real_, nrow = nrow(data), ncol = 5)),
@@ -163,7 +166,7 @@ lr_parse_jaz <- function(filename) {
 
   data_final[match(colnames(data), cornames)] <- data
 
-  return(list("data" = data_final, "metadata" = unname(metadata)))
+  return(list(data = data_final, metadata = unname(metadata)))
 }
 
 #' @rdname lr_parse_jaz
