@@ -1,7 +1,7 @@
-#' Parse OceanInsight ProcSpec file
+#' Parse OceanOptics ProcSpec file
 #'
-#' Parse OceanInsight (formerly OceanOptics) ProcSpec file.
-#' <https://www.oceaninsight.com/>
+#' Parse OceanOptics/OceanInsight ProcSpec file.
+#' <https://www.oceanoptics.com/>
 #'
 #' @inheritParams lr_parse_generic
 #'
@@ -9,7 +9,7 @@
 #'
 #' @importFrom xml2 read_xml xml_find_all xml_find_first xml_text xml_double
 #'
-#' @references <https://www.oceaninsight.com/support/faqs/software/>
+#' @references <https://www.oceanoptics.com/software/>
 #'
 #' @examples
 #' res <- lr_parse_procspec(system.file("testdata", "procspec_files",
@@ -95,5 +95,5 @@ lr_parse_procspec <- function(filename) {
                 dark_average, white_average, scope_average,
                 dark_boxcar, white_boxcar, scope_boxcar)
 
-  return(list("data" = as.data.frame(specdf), "metadata" = metadata))
+  return(list(data = as.data.frame(specdf), metadata = metadata))
 }
