@@ -1,7 +1,7 @@
 #' Parse SPC binary file
 #'
 #' Parse SPC binary file. (Used by CRAIC <https://www.microspectra.com/> and
-#' OceanInsight <https://www.oceaninsight.com/>)
+#' OceanOptics <https://www.oceanoptics.com/>)
 #'
 #' @inheritParams lr_parse_generic
 #'
@@ -46,13 +46,13 @@ lr_parse_spc <- function(filename) {
   processed <- readBin(f, "numeric", n = dat_len, size = 4, endian = "little")
 
   data <- cbind(wl,
-                "dark" = NA_real_,
-                "white" = NA_real_,
-                "scope" = NA_real_,
+                dark = NA_real_,
+                white = NA_real_,
+                scope = NA_real_,
                 processed)
 
   metadata <- rep(NA_character_, 13)
 
-  return(list("data" = as.data.frame(data), "metadata" = metadata))
+  return(list(data = as.data.frame(data), metadata = metadata))
 
 }
