@@ -17,7 +17,7 @@ head(res)
 res <- lr_get_spec(where = "data", ext = "procspec", subdir = TRUE, ignore.case = FALSE)
 
 ## -----------------------------------------------------------------------------
-res <- lr_get_spec(where = "data/puffin", ext = "procspec", interpolate = FALSE)
+res <- lr_get_spec(where = file.path("data", "puffin"), ext = "procspec", interpolate = FALSE)
 head(res)
 
 ## -----------------------------------------------------------------------------
@@ -25,5 +25,5 @@ res <- lr_get_metadata(where = "data", ext = c("trt", "procspec"), subdir = TRUE
 head(res)
 
 ## ----eval = FALSE-------------------------------------------------------------
-#  lr_convert_tocsv(where = "data", ext = "procspec", subdir = TRUE)
+# lr_convert_tocsv(where = "data", ext = "procspec", subdir = TRUE)
 
