@@ -18,14 +18,13 @@ white_data <- lr_parse_procspec(
 )
 
 ## -----------------------------------------------------------------------------
-reflect_data = data.frame(reflect_data[[1]])
-white_data = data.frame(white_data[[1]])
+reflect_data <- data.frame(reflect_data[[1]])
+white_data <- data.frame(white_data[[1]])
 
 ## -----------------------------------------------------------------------------
 all.equal(reflect_data$wl, white_data$wl)
 
 ## -----------------------------------------------------------------------------
-res <- (reflect_data$scope - reflect_data$dark) / 
-       (white_data$white - white_data$dark)
+res <- (reflect_data$scope - reflect_data$dark) / (white_data$white - white_data$dark)
 head(res)
 
